@@ -4,7 +4,6 @@ use 5.010001;
 use locale;
 use Log::ger;
 use Moo;
-use experimental 'smartmatch';
 no if $] >= 5.021_006, warnings => "locale";
 extends 'Org::Element';
 
@@ -12,9 +11,9 @@ use List::MoreUtils qw(firstidx);
 use Time::HiRes qw(gettimeofday tv_interval);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-06-23'; # DATE
+our $DATE = '2023-07-12'; # DATE
 our $DIST = 'Org-Parser'; # DIST
-our $VERSION = '0.558'; # VERSION
+our $VERSION = '0.559'; # VERSION
 
 has tags                    => (is => 'rw');
 has todo_states             => (is => 'rw');
@@ -267,9 +266,10 @@ sub _parse {
         } elsif ($m{setting}) {
 
             require Org::Element::Setting;
+            my $uc_setting_name = uc($m{setting_name});
             if ($m{setting_indent} &&
-                    !(uc($m{setting_name}) ~~
-                          @{Org::Element::Setting->indentable_settings})) {
+                    !(grep { $_ eq $uc_setting_name }
+                      @{Org::Element::Setting->indentable_settings})) {
                 push @text, $m{setting};
                 next;
             } else {
@@ -405,7 +405,7 @@ sub _parse {
                 $title =~ s/^\s+//;
                 $el->is_todo(1);
                 $el->todo_state($state);
-                $el->is_done($state ~~ @{ $self->done_states } ? 1:0);
+                $el->is_done((grep { $_ eq $state } @{ $self->done_states }) ? 1:0);
             }
 
             # recognize priority cookie
@@ -809,7 +809,7 @@ Org::Document - Represent an Org document
 
 =head1 VERSION
 
-This document describes version 0.558 of Org::Document (from Perl distribution Org-Parser), released on 2022-06-23.
+This document describes version 0.559 of Org::Document (from Perl distribution Org-Parser), released on 2023-07-12.
 
 =head1 SYNOPSIS
 
@@ -936,13 +936,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2021, 2020, 2019, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2021, 2020, 2019, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
