@@ -2,16 +2,16 @@ package Org::Element::Drawer;
 
 use 5.010;
 use locale;
+
 use Moo;
-use experimental 'smartmatch';
 extends 'Org::Element';
 with 'Org::ElementRole';
 with 'Org::ElementRole::Block';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-06-23'; # DATE
+our $DATE = '2023-07-12'; # DATE
 our $DIST = 'Org-Parser'; # DIST
-our $VERSION = '0.558'; # VERSION
+our $VERSION = '0.559'; # VERSION
 
 has name => (is => 'rw');
 has properties => (is => 'rw');
@@ -23,7 +23,7 @@ sub BUILD {
 
     if ($pass == 2) {
         die "Unknown drawer name: ".$self->name
-            unless $self->name ~~ @{$doc->drawer_names};
+            unless grep { $_ eq $self->name } @{$doc->drawer_names};
     }
 }
 
@@ -59,7 +59,7 @@ Org::Element::Drawer - Represent Org drawer
 
 =head1 VERSION
 
-This document describes version 0.558 of Org::Element::Drawer (from Perl distribution Org-Parser), released on 2022-06-23.
+This document describes version 0.559 of Org::Element::Drawer (from Perl distribution Org-Parser), released on 2023-07-12.
 
 =head1 DESCRIPTION
 
@@ -126,13 +126,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2021, 2020, 2019, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2021, 2020, 2019, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
