@@ -3,16 +3,16 @@ package Org::Element::Headline;
 use 5.010;
 use locale;
 use Log::ger;
+
 use Moo;
-use experimental 'smartmatch';
 extends 'Org::Element';
 with 'Org::ElementRole';
 with 'Org::ElementRole::Block';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-06-23'; # DATE
+our $DATE = '2023-07-12'; # DATE
 our $DIST = 'Org-Parser'; # DIST
-our $VERSION = '0.558'; # VERSION
+our $VERSION = '0.559'; # VERSION
 
 has level => (is => 'rw');
 has title => (is => 'rw');
@@ -59,14 +59,14 @@ sub get_tags {
             my ($el, $parent) = @_;
             return 1 unless $parent->isa('Org::Element::Headline');
             if ($parent->tags) {
-                for (@{ $parent->tags }) {
-                    push @res, $_ unless $_ ~~ @res;
+                for my $tag (@{ $parent->tags }) {
+                    push @res, $tag unless grep { $_ eq $tag } @res;
                 }
             }
             1;
         });
-    for (@{ $self->document->tags }) {
-        push @res, $_ unless $_ ~~ @res;
+    for my $tag (@{ $self->document->tags }) {
+        push @res, $tag unless grep { $_ eq $tag } @res;
     }
     @res;
 }
@@ -304,7 +304,7 @@ Org::Element::Headline - Represent Org headline
 
 =head1 VERSION
 
-This document describes version 0.558 of Org::Element::Headline (from Perl distribution Org-Parser), released on 2022-06-23.
+This document describes version 0.559 of Org::Element::Headline (from Perl distribution Org-Parser), released on 2023-07-12.
 
 =head1 DESCRIPTION
 
@@ -466,13 +466,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2021, 2020, 2019, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2021, 2020, 2019, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
