@@ -6,9 +6,9 @@ use Moo;
 extends 'Org::Element';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-06-23'; # DATE
+our $DATE = '2023-07-12'; # DATE
 our $DIST = 'Org-Parser'; # DIST
-our $VERSION = '0.558'; # VERSION
+our $VERSION = '0.559'; # VERSION
 
 sub as_string {
     my ($self) = @_;
@@ -52,7 +52,7 @@ Org::Element::TableRow - Represent Org table row
 
 =head1 VERSION
 
-This document describes version 0.558 of Org::Element::TableRow (from Perl distribution Org-Parser), released on 2022-06-23.
+This document describes version 0.559 of Org::Element::TableRow (from Perl distribution Org-Parser), released on 2023-07-12.
 
 =head1 DESCRIPTION
 
@@ -99,13 +99,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2021, 2020, 2019, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2021, 2020, 2019, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
